<?php
$lan = array(
 'Deleting' => 'Apagando',
 'Done' => 'Conclu&iacute;do',
 'events' => 'eventos',
 'Listing' => 'Listando',
 'to' => 'a',
 'Listing 1 to 50' => 'Listando 1 a 50',
 'Are you sure you want to delete all events older than 2 months?' => 'Voc&ecirc; tem certeza que quer apagar todos os eventos com mais de 2 meses?',
 'Delete all (&gt; 2 months old)' => 'Apagar todos (&gt; com mais de 2 meses)',
 'Are you sure you want to delete all events matching this filter?' => 'Voc&ecirc; tem certeza que quer apagar todos os eventos selecionados por este filtro?',
 'Delete all' => 'Apagar todos',
 'No events available' => 'Nenhum evento dispon&iacute;vel',
 'Filter' => 'Filtro',
 'Exclude filter' => 'Excluir filtro',
 'del' => 'apagar', # as in short for delete
 'date' => 'data',
 'message' => 'mensagem', 
 'events' => 'Eventos',
 'page' => 'p&aacute;gina',
);
?>
